@@ -253,7 +253,7 @@ class __AptDpkgPackageInfo(PackageInfo):
                     if not words:
                         apport.warning('%s contains empty line, ignoring line', sumfile)
                         continue
-                    s = os.stat('/' + words[-1].decode('UTF-8'))
+                    s = os.stat(('/' + words[-1].decode('UTF-8')).encode('UTF-8'))
                     if max(s.st_mtime, s.st_ctime) <= max_time:
                         continue
                 except OSError:
